@@ -8,9 +8,23 @@ use base qw/File::Assets::Filter/;
 use Digest;
 use File::Assets;
 
+for my $ii (qw/content_digest content_digester/) {
+    no strict 'refs';
+    *$ii = sub {
+        my $self = shift;
+        return $self->stash->{$ii} unless @_;
+        return $self->stash->{$ii} = shift;
+    };
+}
+
+sub signature {
+    return "collect";
+}
+
 my %default = (qw/
         skip_single 0
         skip_if_exists 0
+        skip_inline 1
         check_content 0
         content_digest 0
         check_age 1 
@@ -26,7 +40,7 @@ sub new {
         $self->cfg->{$setting} = exists $_{$setting} ? $_{$setting} : $value;
     }
     $self->cfg->{content_digest} = 1 if $self->cfg->{check_content};
-    $self->cfg->{content_digest} = 1 if $self->cfg->{output} && $self->cfg->{output} =~ m/%D/;
+    # TODO Set content_digest if output_path is 1?
     return $self;
 }
 
@@ -37,7 +51,7 @@ sub pre {
     return 0 if $self->skip_if_exists;
 
     if ($self->cfg->{content_digest}) {
-        $self->stash->{content_digester} = File::Assets::Util->digest;
+        $self->content_digester(File::Assets::Util->digest);
     }
 
     return 1;
@@ -46,7 +60,7 @@ sub pre {
 sub process {
     my $self = shift;
     $self->SUPER::process(@_);
-    if (my $digester = $self->stash->{content_digester}) {
+    if (my $digester = $self->content_digester) {
         my $asset = shift;
         $digester->add($asset->content_digest."\n");
     }
@@ -56,18 +70,17 @@ sub post {
     my $self = shift;
     $self->SUPER::post(@_);
 
-    my $assets = shift;
-    my $matched = shift;
+    my $matched = $self->matched;
 
     return unless @$matched;
 
     return if $self->cfg->{skip_single} && 1 == @$matched;
 
-    if (my $digester = $self->stash->{content_digester}) {
-        $self->stash->{content_digest} = $digester->hexdigest;
+    if (my $digester = $self->content_digester) {
+        $self->content_digest($digester->hexdigest);
     }
 
-    my $type = $self->find_type;
+#    my $type = $self->find_type;
 
     return if $self->skip_if_exists;
 
@@ -78,7 +91,7 @@ sub post {
         $self->build;
     }
 
-    $self->replace;
+    $self->substitute;
 }
 
 sub skip_if_exists {
@@ -109,7 +122,7 @@ sub should_build {
 
     if ($self->cfg->{check_age}) {
         my $mtime = $self->mtime;
-        return 1 if $mtime > $self->asset->mtime;
+        return 1 if $mtime > $self->output_asset->mtime;
     }
 
     if ($self->cfg->{check_digest}) {
@@ -122,6 +135,14 @@ sub should_build {
     return 0;
 }
 
+sub match {
+    my $self = shift;
+    my $asset = shift;
+    my $match = shift;
+    return $self->SUPER::match($asset, $match &&
+        (! $asset->inline || ! $self->cfg->{skip_inline}));
+}
+
 sub check_digest_file {
     my $self = shift;
     my $digest = $self->digest;
@@ -131,53 +152,67 @@ sub check_digest_file {
     return $file;
 }
 
-sub asset {
-    my $self = shift;
-    return $self->stash->{asset} ||= do {
-        my $type = shift || $self->find_type;
-        my $path = File::Assets::Util->build_asset_path(undef, # $output
-            assets => $self->assets,
-            filter => $self,
-            name => $self->assets->name,
-            type => $type,
-            digest => $self->digest,
-            content_digest => $self->content_digest,
-        );
-        return File::Assets::Util->parse_asset_by_path(
-            path => $path,
-            base => $self->assets->rsc,
-            type => $type,
-        );
-    }
-}
-
-sub content_digest {
-    my $self = shift;
-    return $self->stash->{content_digest};
-}
+#sub asset {
+#    my $self = shift;
+#    return $self->stash->{asset} ||= do {
+#        my $type = shift || $self->find_type;
+#        my $path = File::Assets::Util->build_asset_path(undef, # $output
+#            assets => $self->assets,
+#            filter => $self,
+#            name => $self->assets->name,
+#            type => $type,
+#            digest => $self->digest,
+#            content_digest => $self->content_digest,
+#        );
+#        return File::Assets::Util->parse_asset_by_path(
+#            path => $path,
+#            base => $self->assets->rsc,
+#            type => $type,
+#        );
+#    }
+#}
 
 sub build {
     my $self = shift;
 
     my $content = $self->build_content;
 
-    $self->asset->write($content) if defined $content;
+    my $output_asset = $self->output_asset;
+
+    $output_asset->write($content) if defined $content;
+
+    return $output_asset;
 }
 
-sub replace {
+sub output_asset {
     my $self = shift;
+    return $self->stash->{output_asset} ||= do {
+        $self->assets->output_asset($self);
+    };
+}
 
-    my $assets = $self->stash->{assets};
+sub substitute {
+    my $self = shift;
+    my $asset = shift || $self->output_asset;
+
+    my $slice = $self->slice;
     my $matched = $self->matched;
     my $top_match = $matched->[0];
     my $top_asset = $top_match->{asset};
 
     for my $match (reverse @$matched) {
         my $rank = $match->{rank};
-        splice @$assets, $rank, 1, ();
+        splice @$slice, $rank, 1, ();
     }
 
-    splice @$assets, $top_match->{rank}, 0, $self->asset; 
+    splice @$slice, $top_match->{rank}, 0, $asset; 
+
+#    my $matched = $self->matched;
+#    for my $match (@$matched) {
+#        $match->{asset}->hide;
+#    }
+#
+#    $self->bucket->add_asset($asset);
 }
 
 sub find_type {
@@ -185,7 +220,7 @@ sub find_type {
     my $frob;
     return $frob if $frob = $self->type;
     # FIXME Is this a good idea? What happens when you mix types?
-    return $frob if (($frob = $self->stash->{matched}->[0]) && ($frob = $frob->{asset}->type));
+    return $frob if (($frob = $self->matched->[0]) && ($frob = $frob->{asset}->type));
     return undef;
 }
 
