@@ -14,14 +14,9 @@ use vars qw/@EXPORT/;
 
 my $scratch;
 sub scratch {
-    my $self = shift;
-    if (shift) {
-        $scratch->cleanup if $scratch;
-        undef $scratch;
-    }
     return $scratch ||= do {
         t::Test::Scratch->new;
-    };
+    }
 }
 
 my $assets;
@@ -43,7 +38,7 @@ sub compare ($;@) {
             ($kind) = $href =~ m/\.([^.]+)$/ unless $kind;
             %attributes = (%attributes, %{ shift() }) if ref $_[0] eq "HASH";
             if ($kind eq "js") {
-                push @content, SCRIPT({ type => "text/javascript", src => $href, _ => "", %attributes });
+                push @content, SCRIPT({ type => "text/javascript", src => $href, %attributes });
             }
             elsif ($kind =~ m/^css\b/) {
                 my ($type, $media) = split m/-/, $kind;
@@ -71,7 +66,7 @@ sub compare ($;@) {
 }
 
 END {
-    memory_cycle_ok($assets) if Test::Builder->new->{Have_Plan};
+    memory_cycle_ok($assets);
 }
 
 package t::Test::Scratch;
@@ -82,27 +77,7 @@ sub new {
     my $class = shift;
     my $self = $class->SUPER::new(@_, CLEANUP => 0);
     $self->create_tree({
-        (map { $_ => "/* Test file: $_ */\n" } qw(
-
-            static/css/apple.css
-            static/css/banana.css
-            static/js/apple.js
-            js/grape.js
-            js/plum.js
-            css/grape.css
-            other/pear.js
-
-            static/apple.png
-            static/banana.png
-            static/apple.gif
-            grape.jpg
-            plum.jpeg
-            grape.png
-            apple.gif
-            other/pear.tiff
-
-        )),
-
+        (map { $_ => "/* Test file: $_ */\n" } qw(static/css/apple.css static/css/banana.css static/js/apple.js)),
         'static/css/cherry.css' => <<_END_,
 div.cherry {
     font-weight: bold;
